#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-simple
version:              0.4.5
visibility:           public
id:                   network-simple-0.4.5-8y5NRuYPLVvAiFRiOwibvL
key:                  network-simple-0.4.5-8y5NRuYPLVvAiFRiOwibvL
license:              BSD-3-Clause
copyright:            Copyright (c) Renzo Carbonara 2013-2019
maintainer:           renλren.zone
author:               Renzo Carbonara
homepage:             https://github.com/k0001/network-simple
synopsis:             Simple network sockets usage patterns.
description:
    This module exports functions that abstract simple network socket
    usage patterns.

    See the @changelog.md@ file in the source distribution to learn about any
    important changes between versions.

category:             Network
abi:                  f59cc84fbf637e0169e7e34ff812b5a1
exposed:              True
exposed-modules:      Network.Simple.TCP
hidden-modules:       Network.Simple.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-simple-0.4.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-simple-0.4.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-simple-0.4.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-simple
hs-libraries:         HSnetwork-simple-0.4.5-8y5NRuYPLVvAiFRiOwibvL
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o
    network-bsd-2.8.1.0-5jWyJQYzAT48Le8IwU4Mfy
    safe-exceptions-0.1.7.4-Ed9tl0V54XFHH60bY3H5co
    socks-0.6.1-3j198si5G0i8N7Deqc6sG5 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-network-simple/html/network-simple.haddock

haddock-html:         /usr/share/doc/haskell-network-simple/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

